<!--
* Klish Group, Inc. 2017 - 2018 – MIT License
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">

	<xsl:template name="link-datum">
		<xsl:param name="node"/> 
		<xsl:param name="class"/>
		<xsl:param name="contextEdit"/>
		<span>	
			<xsl:attribute name="in-context-edit">
				<xsl:value-of select="$contextEdit"/>
			</xsl:attribute> 
			<a>
				<xsl:attribute name="href">
					<xsl:value-of select="$node/Datum[@ID='LinkURL']"/>
				</xsl:attribute>
				<xsl:if test="$node/Datum[@ID='OpenNewWindow']/Option[@Selected='true']/Value = 'yes'">
					<xsl:attribute name="target">
						<xsl:text>_blank</xsl:text>
					</xsl:attribute>
				</xsl:if>
				<xsl:if test="not($class = '')">
					<xsl:attribute name="class">
						<xsl:value-of select="$class"/>
					</xsl:attribute>
				</xsl:if>	
				<xsl:value-of select="$node/Datum[@ID='LinkLabel']"/>
			</a>
		</span>
	</xsl:template>
	<xsl:template name="link-dcr">
		<xsl:param name="node"/> 
		<xsl:param name="class"/>
		<xsl:param name="contextEdit"/>
		<xsl:param name="dcrItemPaths"/>
		<span>	
			<xsl:attribute name="in-context-edit">
				<xsl:value-of select="$contextEdit"/>
			</xsl:attribute> 
			<xsl:attribute name="dcr-item-paths">
				<xsl:value-of select="$dcrItemPaths"/>
			</xsl:attribute> 
			<a>
				<xsl:attribute name="href">
					<xsl:value-of select="$node/LinkURL"/>
				</xsl:attribute>
				<xsl:if test="$node/OpenNewWindow = 'yes'">
					<xsl:attribute name="target">
						<xsl:text>_blank</xsl:text>
					</xsl:attribute>
				</xsl:if>
				<xsl:if test="not($class = '')">
					<xsl:attribute name="class">
						<xsl:value-of select="$class"/>
					</xsl:attribute>
				</xsl:if>
				<xsl:value-of select="$node/LinkLabel" disable-output-escaping="yes"/>
			</a>
		</span>
	</xsl:template>
	<xsl:template name="link-sitemap">
		<xsl:param name="node"/> 
		<xsl:param name="class"/>
		<xsl:param name="displayCaret"/>
		<xsl:param name="dataToggle"/>
		<a>
			<xsl:if test="not($dataToggle = '')">
				<xsl:attribute name="data-toggle">
					<xsl:value-of select="$dataToggle"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="href">
				<xsl:choose>						
					<xsl:when test="$node/link/@type ='url'"><xsl:value-of select="$node/link/value"/></xsl:when>
					<xsl:when test="not($node/link/value = '')">$PAGE_LINK[<xsl:value-of select="$node/link/value"/>]</xsl:when>
					<xsl:otherwise>#</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:if test="not($class = '')">
				<xsl:attribute name="class">
					<xsl:value-of select="$class"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="target">
				<xsl:value-of select="$node/link/@target"/>
			</xsl:attribute>
			<xsl:value-of select="$node/label"/>
			<xsl:if test="$displayCaret = 'yes'">
				<span class="caret"/>
			</xsl:if>
		</a>
	</xsl:template>
	<xsl:template name="image">
		<xsl:param name="imagePath"/> 
		<xsl:param name="altText"/>
		<xsl:param name="LinkURL"/>
		<xsl:param name="class"/>
		<xsl:param name="linkClass"/>
		<xsl:param name="contextEdit"/>
		<span>	
			<xsl:attribute name="in-context-edit">
				<xsl:value-of select="$contextEdit"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="not($LinkURL = '')">
					<a>
						<xsl:if test="not($linkClass = '')">
							<xsl:attribute name="class">
								<xsl:value-of select="$linkClass"/>
							</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="href">
							<xsl:value-of select="$LinkURL"/>
						</xsl:attribute>

						<img>
							<xsl:if test="not($class = '')">
								<xsl:attribute name="class">
									<xsl:value-of select="$class"/>
								</xsl:attribute>
							</xsl:if>
							<xsl:attribute name="alt">
								<xsl:value-of select="$altText"/>
							</xsl:attribute>
							<xsl:attribute name="src">
								<xsl:value-of select="$imagePath"/>
							</xsl:attribute>
						</img>
					</a>
				</xsl:when>
				<xsl:otherwise>
					<img>
						<xsl:if test="not($class = '')">
							<xsl:attribute name="class">
								<xsl:value-of select="$class"/>
							</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="alt">
							<xsl:value-of select="$altText"/>
						</xsl:attribute>
						<xsl:attribute name="src">
							<xsl:value-of select="$imagePath"/>
						</xsl:attribute>
					</img>			
				</xsl:otherwise>
			</xsl:choose>		
		</span>
	</xsl:template>
	<xsl:template name="image-dcr">
		<xsl:param name="node"/> 
		<xsl:param name="class"/>
		<xsl:param name="linkClass"/>
		<xsl:param name="spanClass"/>
		<xsl:param name="contextEdit"/>
		<xsl:param name="dcrItemPaths"/>
		<span>	
			<xsl:if test="not($spanClass = '')">
				<xsl:attribute name="class">
					<xsl:value-of select="$spanClass"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="in-context-edit">
				<xsl:value-of select="$contextEdit"/>
			</xsl:attribute>
			<xsl:attribute name="dcr-item-paths">
				<xsl:value-of select="$dcrItemPaths"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="$node/Link/LinkURL">
					<a>
						<xsl:if test="not($linkClass = '')">
							<xsl:attribute name="class">
								<xsl:value-of select="$linkClass"/>
							</xsl:attribute>
						</xsl:if>
						<xsl:if test="$node/Link/OpenNewWindow = 'yes'">
							<xsl:attribute name="target">
								<xsl:text>_blank</xsl:text>
							</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="href">
							<xsl:value-of select="$node/Link/LinkURL"/>
						</xsl:attribute>
						<img>
							<xsl:if test="not($class = '')">
								<xsl:attribute name="class">
									<xsl:value-of select="$class"/>
								</xsl:attribute>
							</xsl:if>
							<xsl:attribute name="alt">
								<xsl:value-of select="$node/AltText"/>
							</xsl:attribute>
							<xsl:attribute name="src">
								<xsl:value-of select="$node/ImagePath"/>
							</xsl:attribute>
						</img>
					</a>
				</xsl:when>
				<xsl:otherwise>
					<img>
						<xsl:if test="not($class = '')">
							<xsl:attribute name="class">
								<xsl:value-of select="$class"/>
							</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="alt">
							<xsl:value-of select="$node/AltText"/>
						</xsl:attribute>
						<xsl:attribute name="src">
							<xsl:value-of select="$node/ImagePath"/>
						</xsl:attribute>
					</img>			
				</xsl:otherwise>
			</xsl:choose>		
		</span>
	</xsl:template>
</xsl:stylesheet>